### Recommenders 
If you have trained m pipelines on n datasets, recommenders allow you to get proposals for a new dataset based on the accuracy of the previous performance of the pipelines. We have a simple implementation of the recommender system in the submodule called [recommendation](https://github.com/HDI-Project/BTB/tree/master/btb/recommendation). 

We will be providing a few examples soon.
